==> nuntio_hera-0.1.10.tar.gz: lib/hera_app/hera_app.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:nuntio_hera/hera_app/helpers.dart';
import 'package:nuntio_hera/hera_app/login_screen.dart';
import 'package:nuntio_core/nuntio_theme.dart';
import 'package:nuntio_core/models/hera.pb.dart';
import 'package:nuntio_hera/hera/hera.dart';
import 'package:nuntio_hera/hera/models/auth.dart';
import 'hera_localizations.dart';

class HeraApp extends StatefulWidget {
  const HeraApp({
    super.key,
    required this.child,
    this.excludeAuthMechanisms,
    this.excludeOidcProviders,
    this.logo,
    this.theme,
    this.darkTheme,
    this.highContrastTheme,
    this.highContrastDarkTheme,
    this.themeMode = ThemeMode.system,
    this.localizationsDelegates,
  });

  final List<LoginType>? excludeAuthMechanisms;
  final List<OidcProviderType>? excludeOidcProviders;
  final Widget child;
  final Widget? logo;

  /// Default visual properties, like colors fonts and shapes, for this app's
  /// Hera widgets.
  ///
  /// A second [darkTheme] [ThemeData] value, which is used to provide a dark
  /// version of the user interface can also be specified. [themeMode] will
  /// control which theme will be used if a [darkTheme] is provided.
  ///
  /// The default value of this property is the value of [ThemeData.light()].
  ///
  /// See also:
  ///
  ///  * [themeMode], which controls which theme to use.
  ///  * [MediaQueryData.platformBrightness], which indicates the platform's
  ///    desired brightness and is used to automatically toggle between [theme]
  ///    and [darkTheme] in [HeraApp].
  ///  * [ThemeData.brightness], which indicates the [Brightness] of a theme's
  ///    colors.
  final ThemeData? theme;

  /// The [ThemeData] to use when a 'dark mode' is requested by the system.
  ///
  /// Some host platforms allow the users to select a system-wide 'dark mode',
  /// or the application may want to offer the user the ability to choose a
  /// dark theme just for this application. This is theme that will be used for
  /// such cases. [themeMode] will control which theme will be used.
  ///
  /// This theme should have a [ThemeData.brightness] set to [Brightness.dark].
  ///
  /// Uses [theme] instead when null. Defaults to the value of
  /// [ThemeData.light()] when both [darkTheme] and [theme] are null.
  ///
  /// See also:
  ///
  ///  * [themeMode], which controls which theme to use.
  ///  * [MediaQueryData.platformBrightness], which indicates the platform's
  ///    desired brightness and is used to automatically toggle between [theme]
  ///    and [darkTheme] in [MaterialApp].
  ///  * [ThemeData.brightness], which is typically set to the value of
  ///    [MediaQueryData.platformBrightness].
  final ThemeData? darkTheme;

  /// The [ThemeData] to use when 'high contrast' is requested by the system.
  ///
  /// Some host platforms (for example, iOS) allow the users to increase
  /// contrast through an accessibility setting.
  ///
  /// Uses [theme] instead when null.
  ///
  /// See also:
  ///
  ///  * [MediaQueryData.highContrast], which indicates the platform's
  ///    desire to increase contrast.
  final ThemeData? highContrastTheme;

  /// The [ThemeData] to use when a 'dark mode' and 'high contrast' is requested
  /// by the system.
  ///
  /// Some host platforms (for example, iOS) allow the users to increase
  /// contrast through an accessibility setting.
  ///
  /// This theme should have a [ThemeData.brightness] set to [Brightness.dark].
  ///
  /// Uses [darkTheme] instead when null.
  ///
  /// See also:
  ///
  ///  * [MediaQueryData.highContrast], which indicates the platform's
  ///    desire to increase contrast.
  final ThemeData? highContrastDarkTheme;

  /// Determines which theme will be used by the application if both [theme]
  /// and [darkTheme] are provided.
  ///
  /// If set to [ThemeMode.system], the choice of which theme to use will
  /// be based on the user's system preferences. If the [MediaQuery.platformBrightnessOf]
  /// is [Brightness.light], [theme] will be used. If it is [Brightness.dark],
  /// [darkTheme] will be used (unless it is null, in which case [theme]
  /// will be used.
  ///
  /// If set to [ThemeMode.light] the [theme] will always be used,
  /// regardless of the user's system preference.
  ///
  /// If set to [ThemeMode.dark] the [darkTheme] will be used
  /// regardless of the user's system preference. If [darkTheme] is null
  /// then it will fallback to using [theme].
  ///
  /// The default value is [ThemeMode.system].
  ///
  /// See also:
  ///
  ///  * [theme], which is used when a light mode is selected.
  ///  * [darkTheme], which is used when a dark mode is selected.
  ///  * [ThemeData.brightness], which indicates to various parts of the
  ///    system what kind of theme is being used.
  final ThemeMode? themeMode;

  /// The delegates for this app's [Localizations] widget.
  ///
  /// The delegates collectively define all of the localized resources
  /// for this application's [Localizations] widget.
  ///
  /// Internationalized apps that require translations for one of the locales
  /// listed in [GlobalHeraLocalizations] should specify this parameter
  /// and list the [supportedLocales] that the application can handle.
  ///
  /// ```dart
  /// import 'package:flutter_localizations/flutter_localizations.dart';
  /// HeraApp(
  ///   localizationsDelegates: [
  ///     // ... app-specific localization delegate[s] here
  ///     GlobalHeraLocalizations.delegate,
  ///     GlobalMercuryLocalizations.delegate,
  ///   ],
  ///   supportedLocales: [
  ///     const Locale('en', 'US'), // English
  ///     const Locale('da', 'DK'), // Danish
  ///     // ... other locales the app supports
  ///   ],
  ///   // ...
  /// )
  /// ```
  ///
  /// ## Adding localizations for a new locale
  ///
  /// The information that follows applies to the unusual case of an app
  /// adding translations for a language not already supported by
  /// [GlobalHeraLocalizations].
  ///
  /// Delegates that produce [HeraLocalizations] and [MercuryLocalizations]
  /// are included automatically. Apps can provide their own versions of these
  /// localizations by creating implementations of
  /// [LocalizationsDelegate<HeraLocalizations>] or
  /// [LocalizationsDelegate<MercuryLocalizations>] whose load methods return
  /// custom versions of [HeraLocalizations] or [MercuryLocalizations].
  ///
  /// For example: to add support to [heraLocalizations] for a
  /// locale it doesn't already support, say `const Locale('foo', 'BR')`,
  /// one could just extend [DefaultHeraLocalizations]:
  ///
  /// ```dart
  /// class FooLocalizations extends DefaultHeraLocalizations {
  ///   FooLocalizations(Locale locale) : super(locale);
  ///   @override
  ///   String get okButtonLabel {
  ///     if (locale == const Locale('foo', 'BR'))
  ///       return 'foo';
  ///     return super.okButtonLabel;
  ///   }
  /// }
  ///
  /// ```
  ///
  /// A `FooLocalizationsDelegate` is essentially just a method that constructs
  /// a `FooLocalizations` object. We return a [SynchronousFuture] here because
  /// no asynchronous work takes place upon "loading" the localizations object.
  ///
  /// ```dart
  /// class FooLocalizationsDelegate extends LocalizationsDelegate<HeraLocalizations> {
  ///   const FooLocalizationsDelegate();
  ///   @override
  ///   Future<FooLocalizations> load(Locale locale) {
  ///     return SynchronousFuture(FooLocalizations(locale));
  ///   }
  ///   @override
  ///   bool shouldReload(FooLocalizationsDelegate old) => false;
  /// }
  /// ```
  ///
  /// Constructing a [HeraApp] with a `FooLocalizationsDelegate` overrides
  /// the automatically included delegate for [HeraLocalizations] because
  /// only the first delegate of each [LocalizationsDelegate.type] is used and
  /// the automatically included delegates are added to the end of the app's
  /// [localizationsDelegates] list.
  ///
  /// ```dart
  /// HeraApp(
  ///   localizationsDelegates: [
  ///     const FooLocalizationsDelegate(),
  ///   ],
  ///   // ...
  /// )
  /// ```
  /// See also:
  ///
  ///  * [supportedLocales], which must be specified along with
  ///    [localizationsDelegates].
  ///  * [GlobalHeraLocalizations], a [localizationsDelegates] value
  ///    which provides Hera localizations for many languages.
  ///  * The Flutter Internationalization Tutorial,
  ///    <https://flutter.dev/tutorials/internationalization/>.
  final Iterable<LocalizationsDelegate<dynamic>>? localizationsDelegates;

  // on authenticated go to child;
  @override
  State<HeraApp> createState() => _HeraAppState();
}

class _HeraAppState extends State<HeraApp> {
  late AuthState _authState;
  late HeraConfig _config;
  late TextInputType _inputType;

  Future<void> initialize() async {
    // get config used to login
    _config = await Hera.initializeAuth();
    if (await Hera.isAuthenticated()) {
      setState(() {
        _authState = AuthState.authenticated;
        _inputType = getInputType(_config.supportedLoginMechanisms);
      });
      return;
    }
    // do not display oidc proivers that are not enabled
    _config.oidcProviders.removeWhere((key, value) =>
        !value.enabled ||
        widget.excludeOidcProviders?.contains(value.type) == true);
    _config.supportedLoginMechanisms.removeWhere(
        (element) => widget.excludeAuthMechanisms?.contains(element) ?? false);
    setState(() {
      _inputType = getInputType(_config.supportedLoginMechanisms);
      _authState = AuthState.notAuthenticated;
    });
  }

  @override
  void initState() {
    Hera.onLogout = () {
      setState(() {
        _authState = AuthState.notAuthenticated;
      });
    };
    setState(() {
      _authState = AuthState.loading;
    });
    initialize();
    super.initState();
  }

  // Combine the Localizations for Hera with the ones contributed
  // by the localizationsDelegates parameter, if any. Only the first delegate
  // of a particular LocalizationsDelegate.type is loaded so the
  // localizationsDelegate parameter can be used to override
  // _HeraLocalizationsDelegate.
  Iterable<LocalizationsDelegate<dynamic>> get _localizationsDelegates {
    return <LocalizationsDelegate<dynamic>>[
      if (widget.localizationsDelegates != null)
        ...widget.localizationsDelegates!,
      DefaultHeraLocalizations.delegate,
      //TODO: DefaultMerucuryLocalizations.delegate,
    ];
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      localizationsDelegates: _localizationsDelegates,
      theme: widget.theme ?? nuntioLightTheme,
      darkTheme: widget.darkTheme ?? nuntioDarkTheme,
      highContrastTheme: widget.highContrastDarkTheme,
      highContrastDarkTheme: widget.highContrastDarkTheme,
      themeMode: widget.themeMode,
      home: Builder(
        builder: (context) {
          switch (_authState) {
            case AuthState.loading:
              return Center(
                child: CircularProgressIndicator(),
              );
            case AuthState.authenticated:
              return widget.child;
            case AuthState.notAuthenticated:
              return LoginScreen(
                inputType: _inputType,
                config: _config,
                onAuthenticated: (BuildContext context) {
                  initialize();
                },
              );
            default:
              return SizedBox(child: Text("error"));
          }
        },
      ),
    );
  }
}

class Test extends DefaultHeraLocalizations {
  @override
  String get next => "Forsæt";
}

==> nuntio_hera-0.1.13.tar.gz: lib/hera_app/hera_app.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:nuntio_hera/hera_app/helpers.dart';
import 'package:nuntio_hera/hera_app/login_screen.dart';
import 'package:nuntio_core/nuntio_theme.dart';
import 'package:nuntio_core/models/hera.pb.dart';
import 'package:nuntio_hera/hera/hera.dart';
import 'package:nuntio_hera/hera/models/auth.dart';
import 'hera_localizations.dart';

class HeraApp extends StatefulWidget {
  const HeraApp({
    super.key,
    required this.child,
    this.excludeAuthMechanisms,
    this.excludeOidcProviders,
    this.logo,
    this.theme,
    this.darkTheme,
    this.highContrastTheme,
    this.highContrastDarkTheme,
    this.themeMode = ThemeMode.system,
    this.localizationsDelegates,
  });

  final List<LoginType>? excludeAuthMechanisms;
  final List<OidcProviderType>? excludeOidcProviders;
  final Widget child;
  final Widget? logo;

  /// Default visual properties, like colors fonts and shapes, for this app's
  /// Hera widgets.
  ///
  /// A second [darkTheme] [ThemeData] value, which is used to provide a dark
  /// version of the user interface can also be specified. [themeMode] will
  /// control which theme will be used if a [darkTheme] is provided.
  ///
  /// The default value of this property is the value of [ThemeData.light()].
  ///
  /// See also:
  ///
  ///  * [themeMode], which controls which theme to use.
  ///  * [MediaQueryData.platformBrightness], which indicates the platform's
  ///    desired brightness and is used to automatically toggle between [theme]
  ///    and [darkTheme] in [HeraApp].
  ///  * [ThemeData.brightness], which indicates the [Brightness] of a theme's
  ///    colors.
  final ThemeData? theme;

  /// The [ThemeData] to use when a 'dark mode' is requested by the system.
  ///
  /// Some host platforms allow the users to select a system-wide 'dark mode',
  /// or the application may want to offer the user the ability to choose a
  /// dark theme just for this application. This is theme that will be used for
  /// such cases. [themeMode] will control which theme will be used.
  ///
  /// This theme should have a [ThemeData.brightness] set to [Brightness.dark].
  ///
  /// Uses [theme] instead when null. Defaults to the value of
  /// [ThemeData.light()] when both [darkTheme] and [theme] are null.
  ///
  /// See also:
  ///
  ///  * [themeMode], which controls which theme to use.
  ///  * [MediaQueryData.platformBrightness], which indicates the platform's
  ///    desired brightness and is used to automatically toggle between [theme]
  ///    and [darkTheme] in [MaterialApp].
  ///  * [ThemeData.brightness], which is typically set to the value of
  ///    [MediaQueryData.platformBrightness].
  final ThemeData? darkTheme;

  /// The [ThemeData] to use when 'high contrast' is requested by the system.
  ///
  /// Some host platforms (for example, iOS) allow the users to increase
  /// contrast through an accessibility setting.
  ///
  /// Uses [theme] instead when null.
  ///
  /// See also:
  ///
  ///  * [MediaQueryData.highContrast], which indicates the platform's
  ///    desire to increase contrast.
  final ThemeData? highContrastTheme;

  /// The [ThemeData] to use when a 'dark mode' and 'high contrast' is requested
  /// by the system.
  ///
  /// Some host platforms (for example, iOS) allow the users to increase
  /// contrast through an accessibility setting.
  ///
  /// This theme should have a [ThemeData.brightness] set to [Brightness.dark].
  ///
  /// Uses [darkTheme] instead when null.
  ///
  /// See also:
  ///
  ///  * [MediaQueryData.highContrast], which indicates the platform's
  ///    desire to increase contrast.
  final ThemeData? highContrastDarkTheme;

  /// Determines which theme will be used by the application if both [theme]
  /// and [darkTheme] are provided.
  ///
  /// If set to [ThemeMode.system], the choice of which theme to use will
  /// be based on the user's system preferences. If the [MediaQuery.platformBrightnessOf]
  /// is [Brightness.light], [theme] will be used. If it is [Brightness.dark],
  /// [darkTheme] will be used (unless it is null, in which case [theme]
  /// will be used.
  ///
  /// If set to [ThemeMode.light] the [theme] will always be used,
  /// regardless of the user's system preference.
  ///
  /// If set to [ThemeMode.dark] the [darkTheme] will be used
  /// regardless of the user's system preference. If [darkTheme] is null
  /// then it will fallback to using [theme].
  ///
  /// The default value is [ThemeMode.system].
  ///
  /// See also:
  ///
  ///  * [theme], which is used when a light mode is selected.
  ///  * [darkTheme], which is used when a dark mode is selected.
  ///  * [ThemeData.brightness], which indicates to various parts of the
  ///    system what kind of theme is being used.
  final ThemeMode? themeMode;

  /// The delegates for this app's [Localizations] widget.
  ///
  /// The delegates collectively define all of the localized resources
  /// for this application's [Localizations] widget.
  ///
  /// Internationalized apps that require translations for one of the locales
  /// listed in [GlobalHeraLocalizations] should specify this parameter
  /// and list the [supportedLocales] that the application can handle.
  ///
  /// ```dart
  /// import 'package:flutter_localizations/flutter_localizations.dart';
  /// HeraApp(
  ///   localizationsDelegates: [
  ///     // ... app-specific localization delegate[s] here
  ///     GlobalHeraLocalizations.delegate,
  ///     GlobalMercuryLocalizations.delegate,
  ///   ],
  ///   supportedLocales: [
  ///     const Locale('en', 'US'), // English
  ///     const Locale('da', 'DK'), // Danish
  ///     // ... other locales the app supports
  ///   ],
  ///   // ...
  /// )
  /// ```
  ///
  /// ## Adding localizations for a new locale
  ///
  /// The information that follows applies to the unusual case of an app
  /// adding translations for a language not already supported by
  /// [GlobalHeraLocalizations].
  ///
  /// Delegates that produce [HeraLocalizations] and [MercuryLocalizations]
  /// are included automatically. Apps can provide their own versions of these
  /// localizations by creating implementations of
  /// [LocalizationsDelegate<HeraLocalizations>] or
  /// [LocalizationsDelegate<MercuryLocalizations>] whose load methods return
  /// custom versions of [HeraLocalizations] or [MercuryLocalizations].
  ///
  /// For example: to add support to [heraLocalizations] for a
  /// locale it doesn't already support, say `const Locale('foo', 'BR')`,
  /// one could just extend [DefaultHeraLocalizations]:
  ///
  /// ```dart
  /// class FooLocalizations extends DefaultHeraLocalizations {
  ///   FooLocalizations(Locale locale) : super(locale);
  ///   @override
  ///   String get okButtonLabel {
  ///     if (locale == const Locale('foo', 'BR'))
  ///       return 'foo';
  ///     return super.okButtonLabel;
  ///   }
  /// }
  ///
  /// ```
  ///
  /// A `FooLocalizationsDelegate` is essentially just a method that constructs
  /// a `FooLocalizations` object. We return a [SynchronousFuture] here because
  /// no asynchronous work takes place upon "loading" the localizations object.
  ///
  /// ```dart
  /// class FooLocalizationsDelegate extends LocalizationsDelegate<HeraLocalizations> {
  ///   const FooLocalizationsDelegate();
  ///   @override
  ///   Future<FooLocalizations> load(Locale locale) {
  ///     return SynchronousFuture(FooLocalizations(locale));
  ///   }
  ///   @override
  ///   bool shouldReload(FooLocalizationsDelegate old) => false;
  /// }
  /// ```
  ///
  /// Constructing a [HeraApp] with a `FooLocalizationsDelegate` overrides
  /// the automatically included delegate for [HeraLocalizations] because
  /// only the first delegate of each [LocalizationsDelegate.type] is used and
  /// the automatically included delegates are added to the end of the app's
  /// [localizationsDelegates] list.
  ///
  /// ```dart
  /// HeraApp(
  ///   localizationsDelegates: [
  ///     const FooLocalizationsDelegate(),
  ///   ],
  ///   // ...
  /// )
  /// ```
  /// See also:
  ///
  ///  * [supportedLocales], which must be specified along with
  ///    [localizationsDelegates].
  ///  * [GlobalHeraLocalizations], a [localizationsDelegates] value
  ///    which provides Hera localizations for many languages.
  ///  * The Flutter Internationalization Tutorial,
  ///    <https://flutter.dev/tutorials/internationalization/>.
  final Iterable<LocalizationsDelegate<dynamic>>? localizationsDelegates;

  // on authenticated go to child;
  @override
  State<HeraApp> createState() => _HeraAppState();
}

class _HeraAppState extends State<HeraApp> {
  late AuthState _authState;
  late HeraConfig _config;
  late TextInputType _inputType;

  Future<void> initialize() async {
    // get config used to login
    _config = await Hera.initializeAuth();
    if (await Hera.isAuthenticated()) {
      setState(() {
        _authState = AuthState.authenticated;
        _inputType = getInputType(_config.supportedLoginMechanisms);
      });
      return;
    }
    // do not display oidc proivers that are not enabled
    _config.oidcProviders.removeWhere((key, value) =>
        !value.enabled ||
        widget.excludeOidcProviders?.contains(value.type) == true ||
        widget.excludeAuthMechanisms?.contains(LoginType.OIDC_LOGIN) == true);
    _config.supportedLoginMechanisms.removeWhere(
        (element) => widget.excludeAuthMechanisms?.contains(element) ?? false);
    setState(() {
      _inputType = getInputType(_config.supportedLoginMechanisms);
      _authState = AuthState.notAuthenticated;
    });
  }

  @override
  void initState() {
    Hera.onLogout = () {
      setState(() {
        _authState = AuthState.notAuthenticated;
      });
    };
    setState(() {
      _authState = AuthState.loading;
    });
    initialize();
    super.initState();
  }

  // Combine the Localizations for Hera with the ones contributed
  // by the localizationsDelegates parameter, if any. Only the first delegate
  // of a particular LocalizationsDelegate.type is loaded so the
  // localizationsDelegate parameter can be used to override
  // _HeraLocalizationsDelegate.
  Iterable<LocalizationsDelegate<dynamic>> get _localizationsDelegates {
    return <LocalizationsDelegate<dynamic>>[
      if (widget.localizationsDelegates != null)
        ...widget.localizationsDelegates!,
      DefaultHeraLocalizations.delegate,
      //TODO: DefaultMerucuryLocalizations.delegate,
    ];
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      localizationsDelegates: _localizationsDelegates,
      theme: widget.theme ?? nuntioLightTheme,
      darkTheme: widget.darkTheme ?? nuntioDarkTheme,
      highContrastTheme: widget.highContrastDarkTheme,
      highContrastDarkTheme: widget.highContrastDarkTheme,
      themeMode: widget.themeMode,
      home: Builder(
        builder: (context) {
          switch (_authState) {
            case AuthState.loading:
              return Center(
                child: CircularProgressIndicator(),
              );
            case AuthState.authenticated:
              return widget.child;
            case AuthState.notAuthenticated:
              return LoginScreen(
                inputType: _inputType,
                config: _config,
                onAuthenticated: (BuildContext context) {
                  initialize();
                },
              );
            default:
              return SizedBox(child: Text("error"));
          }
        },
      ),
    );
  }
}

class Test extends DefaultHeraLocalizations {
  @override
  String get next => "Forsæt";
}
